%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%
%% This is the class file for the 'Journal of Structural Dynamics' journal
%% It is based on the standards article class.
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2020-05-14  v0.2  Cédric DUMOULIN, Precision Mechatronic Lab, ULB 
%% 2020-09-10  v0.5  Cédric DUMOULIN, Precision Mechatronic Lab, ULB
%% Change to bibtex 
%% Change to onecolumn 
%% 2020-10-16  v0.5  Cédric DUMOULIN, Precision Mechatronic Lab, ULB
%% Remove lastpage package due to new incompatibility with hyperref / hyperxmp

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Exemple of use is provided in 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{jsdarticle}[2020/09/10 v0.6 JSD journal article class]


\def\review{0}
\DeclareOption{review}{\def\review{1}}
\def\guide{0}
\DeclareOption{guide}{\def\guide{1}}
\def\letter{0}
\DeclareOption{letter}{\def\letter{1}}
\ProcessOptions


%\makeatletter%
%\if\guide1%
%	\def\review{0}
%\fi
%\makeatother

 
\makeatletter%
\if\review1%
  \LoadClass[a4paper,12pt]{article}
  \PassOptionsToPackage{left=2.5cm,right=2.5cm}{geometry}
\else% \@twocolumnfalse
 % \LoadClass[a4paper,10pt,twocolumn]{article}
  \LoadClass[a4paper,10pt]{article}
  \PassOptionsToPackage{left=2cm,right=2cm}{geometry}
\fi
\makeatother


%% Passes and class options to the underlying article class
%\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
%\ProcessOptions

% needed to modify titlepage

%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FONTS PARAMETERS %%%%%
% CHARACTERS

\usepackage[french,spanish,english]{babel}
\usepackage[T1]{fontenc}    %print accent
\usepackage[utf8]{inputenc}   %allow type accent
\usepackage[USenglish]{isodate}

%%% MATH
\usepackage[fleqn]{amsmath}
\setlength{\mathindent}{0.5cm}
\usepackage{mathtools}
\usepackage{relsize}
\allowdisplaybreaks[1]

% FONT STYLES
\renewcommand*{\familydefault}{\sfdefault}
%\usepackage{eulervm}
\usepackage{txfonts,txfontsb}   %Load times for math and text, helvetica scaled if sfdefault

%\usepackage{avant} % Use the Avantgarde font for headings
%\usepackage{mathptmx} % Use the Adobe Times Roman as the default text font together with math symbols from the Sym¬bol, Chancery and Com¬puter Modern fonts 


% COLORS
\usepackage[cmyk]{xcolor}
\definecolor{bookColor}{cmyk}{0 ,0 ,0 ,1}
\definecolor{sdblue}{cmyk}{0.85 ,0.5 ,0.00 ,0.0}
\color{bookColor}

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% GENERAL LAYOUT
\usepackage[nospread]{flushend} %BALANCE COLUMNS
\usepackage{microtype}      %Better typing

\usepackage[
 bindingoffset=0cm,
 bottom = 3cm,
 top=3cm,%showframe, 
 headheight = 20mm,
 footskip=1cm]{geometry}    %MARGINS}

%\setlength{\columnsep}{1cm}

\usepackage[left,modulo]{lineno}

\usepackage{setspace} 
\makeatletter%
\if\review1%
  \onehalfspacing
  \linenumbers
\fi
\makeatother

%%%% NOMENCLATURE
\usepackage{nomencl}
\makenomenclature

\newcommand{\newnomentry}[3]{\nomenclature{#1}{\parbox[t]{0.5\linewidth}{#2}\nomunit{#3}}}
\newcommand{\nomunit}[1]{\renewcommand{\nomentryend}{\hspace*{\fill}#1\hspace{0.3\linewidth}\mbox{}}}

\makeatletter%
\if\review1%
	\renewcommand{\nomunit}[1]{\renewcommand{\nomentryend}{\hspace*{\fill}#1}}
\fi
\makeatother


\setlength{\nomitemsep}{0em}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% FIGURE CAPTION AND TABLE %%%
\usepackage[font=small,labelfont=bf,figurename=Fig.]{caption}
\usepackage{subcaption}
\usepackage{booktabs}
\usepackage{graphicx}

\DeclareGraphicsExtensions{%
  .pdf,.PDF,%
    .png,.PNG,%
    .jpg,.mps,.jpeg,.jbig2,.jb2,.JPG,.JPEG,.JBIG2,.JB2}

\newdimen\figwidth
\makeatletter%
\if\review1%
	\setlength{\figwidth}{0.7\linewidth}  
\else% \@twocolumnfalse
	\setlength{\figwidth}{0.7\linewidth}  
           %\setlength{\figwidth}{\linewidth}
\fi
\makeatother

%%%%% HEADER (FANCYHDR)
%%%%%%%%%%%%%%%%%%%%%%%

\usepackage{authblk}   %Provide new author, affiliation
\renewcommand\Affilfont{\itshape\small}
\newcommand\email[1]{\footnote{\texttt{\url{#1}}}}
%\usepackage{titling}

% Copy the title Command
\let\keeptitle\title  
% Renew the title command (the actual titlte command is keeptitle)
% and copy the value to the variable title
\renewcommand{\title}[1]{\keeptitle{#1}\def\thetitle{#1}}
%

\def\theyearissue{~}
\def\thevolume{~}
\def\theissue{For Review}
\def\thecurdoi{~}

\newcommand{\curpubissue}[5]{
  	\def\theissue{#1}
 	\def\thevolume{#2}
	\def\theyearissue{#3}
	\setcounter{page}{#4} %Actual Page number of the paper
 	\def\thecurdoi{doi:\href{http://dx.doi.org/#5}{#5}}
}

\def\thereceiveddate{~}
\def\theaccepteddate{~}
\def\thepublisheddate{~}
\newcommand{\curpubdates}[3]{
	\def\thereceiveddate{\printdate{#1}}
	\def\theaccepteddate{\printdate{#2}}
	\def\thepublisheddate{\printdate{#3}}
}

\newcommand{\printbibliography}[1]{
\small
\bibliography{#1}
\bibliographystyle{unsrtjsd}
}

%\def\theyearissue{~}
%\newcommand{\yearissue}[1]{
% \def\theyearissue{(#1)}
%}

%\def\thecurdoi{~}
%\newcommand{\curdoi}[1]{
%  \def\thecurdoi{doi:\href{http://dx.doi.org/#1}{#1}}
%}

\makeatletter
\newcommand*{\authors}{%
  \begingroup
    \let\footnote\@gobble% ignore \footnote
    \let\textsuperscript\@gobble% ignore protected \textsuperscript
    \expandafter\let\csname textsuperscript \endcsname\@gobble
    \let\Authfont\relax% do not use a special font
    \def\Authand{, }% separate list of authors by ,
    \ifnum\value{authors}<3 % one ore two authors
      \AB@authlist% show them all
    \else% 3 or more authors
      % show only the first one followed by "et.~al"
      \expandafter\@firstof@authlist\AB@authlist\@nil\ et.~al%
    \fi
  \endgroup
}
\def\@firstof@authlist#1\footnote#2\@nil{#1}% skip all from the first footnote
\makeatother

\usepackage{fancyhdr}
%\usepackage{lastpage}


\lhead{\scriptsize \textit{Journal of Structural Dynamics}, \theissue, (pp. \pageref{FirstPage}-\pageref{TotPages}) \theyearissue \\ \thetitle }

\makeatletter%
\if\guide1%
	\lhead{\scriptsize \textit{Journal of Structural Dynamics} \\ \thetitle }
\fi
\if\letter1%
	\lhead{\scriptsize \textit{Journal of Structural Dynamics} \\ Letter to the Editors} 
\fi
\makeatother

\chead{}
\rhead{}
\lfoot{\scriptsize \thepage \;|\; \thecurdoi}
\cfoot{}
\rfoot{\scriptsize \authors}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\pagestyle{fancy}

% New fancy page style
\fancypagestyle{plain}{
  \pagestyle{fancy}% Duplicate fancy page style
\rhead{\raisebox{-2mm}{\includegraphics[height=18mm]{jsdlogo}}}
%  %\rhead{\raisebox{-0.5\height}{\includegraphics[height=2mm]{jsdlogo}}}
%  \rhead{\includegraphics[height=18mm]{jsdlogo}}
}

\newcommand{\ack}{\section*{Acknowledgements}}
\newcommand{\contrib}{\section*{Authors' Contributions}}


\renewcommand{\appendix}{%
  \section*{\appendixname}% start the appendix
  \addcontentsline{toc}{section}{\appendixname}% add it to the toc
  \counterwithin{figure}{section}% optional, if you want to reset the figure counter
  \counterwithin{equation}{section}% optional, if you want to reset the figure counter
  \counterwithin{table}{section}% optional, if you want to reset the figure counter
  \setcounter{section}{0}% reset counters related to section
  \renewcommand{\thesection}{\Alph{section}}% we want A
  \renewcommand{\thefigure}{\thesection.\arabic{figure}}% optional
}


\usepackage[breaklinks=true,hidelinks,
	allcolors=sdblue,
    bookmarksopen,bookmarksdepth=2,
    colorlinks,
    hypertexnames=false,
  ]{hyperref}
\usepackage{hyperxmp}

\addto\extrasenglish{%
\renewcommand{\figureautorefname}{Fig.}
\renewcommand{\equationautorefname}{Eq.}
\renewcommand{\chapterautorefname}{Chapter}
\renewcommand{\sectionautorefname}{Section}
\renewcommand{\subsectionautorefname}{Section}
\renewcommand{\subsubsectionautorefname}{Section}
\renewcommand{\paragraphautorefname}{Paragraph}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% ENUM %%%%%
\usepackage[inline]{enumitem}

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% BIBLIOGRAPHY
\usepackage[numbers]{natbib}
%\usepackage[backend=bibtex,
%    %defernumbers,
%  style=numeric,
%  sorting=none,
%  %refsection=chapter,
%  giveninits=true,
%  natbib,
%  maxcitenames=1,
%  maxbibnames=5,
%  maxnames=3,
%]{biblatex}


%\renewcommand*{\bibfont}{\footnotesize}
%\setlength\biblabelsep{0.5\biblabelsep}
%
%\renewbibmacro*{url}{%
%    {\iffieldundef{doi}{
%     \iffieldundef{eprint}{}{}}{}}
%    }

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Information for the TITLEPAGE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% RENEW TITLE AND ABSTRACT

%%
\makeatletter

\def\@keywords{Keywords}
\newcommand{\keywords}[1]{
  \def\@keywords{#1}
}
%
\newbox\@abstract%
\renewenvironment{abstract}{%
   %\setlength{\parskip}{6pt}%
   %\setlength{\parindent}{\z@}%
   \global\setbox\@abstract\vbox\bgroup%
   \hsize=\textwidth\linewidth=\textwidth
   \hbox{\rule{\textwidth}{0.5pt}}
   \noindent\ignorespaces%
   \list{}{
      \setlength{\leftmargin}{1cm}%
      \setlength{\rightmargin}{\leftmargin}%
  	 }%
  \item {\bfseries \Large \abstractname}
  \item \relax }
  {%
   	\endlist \par
  	 {\textbf{Keywords:} \@keywords\par}%
%  	 {\if\review0%
%    		\footnotesize
%    		\noindent\textit{Received on \thereceiveddate}, \textit{Accepted on \theaccepteddate}, \textit{Published on \thepublisheddate}
%    		\fi
%   	  }\par%
   	 \hbox{\rule{\textwidth}{0.5pt}}
   	 {\if\review0%
   	 		\if\guide0
   	 			\if\letter0
    			\footnotesize
    			\begin{flushright}
    				\textit{Received on \thereceiveddate}, \textit{Accepted on \theaccepteddate}, \textit{Published on \thepublisheddate}
    			\end{flushright}
    			\fi
    		\fi
      \fi
     }\par%
   \egroup
  }%


%\if\review1%
%  \doublespacing
%  \linenumbers
%\fi


\def\@maketitle{%
  \newpage
  \null
  \vskip 2em%
  \begin{flushleft}%
  \let \footnote \thanks
    {\LARGE \@title \label{FirstPage} \par}%
    \vskip 1.5em%
    {\large
      \lineskip .5em%
        \@author
      \par}%
    \vskip 1em%
    \vskip 1em%
    {\unvbox\@abstract\par}%
    \vskip 1em%
  \end{flushleft}%
  \par 
  \vskip -2em}
  
\makeatother

\usepackage{lipsum}

%


\endinput
